@@ -21,22 +21,25 @@
 #ifndef ADDREMOVEDIALOG_H
 #define ADDREMOVEDIALOG_H
 
-#include <kdialog.h>
+#include <QDialog>
+#include <QStringList>
+class QListWidget;
 
-class KListWidget;
-class QStringList;
-
-class AddRemoveDialog : public KDialog
+class AddRemoveDialog : public QDialog
 {
 public:
     enum ActionType { Add, AddBinary, Remove };
 
-    explicit AddRemoveDialog(ActionType action, QWidget* parent=0);
+    explicit AddRemoveDialog(ActionType action, QWidget *parent = nullptr);
 
-    void setFileList(const QStringList& files);
+    void setFileList(const QStringList &files);
+
+private slots:
+    void slotHelp();
 
 private:
-    KListWidget* m_listBox;
+    QListWidget *m_listBox;
+    QString helpTopic;
 };
 
 #endif // ADDREMOVEDIALOG_H
