@@ -17,12 +17,10 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
-
 #ifndef REPOSITORIES_H
 #define REPOSITORIES_H
 
-class QStringList;
-
+#include <QStringList>
 
 class Repositories
 {
@@ -31,10 +29,8 @@ public:
     static QStringList readConfigFile();
 };
 
-
 #endif
 
-
 // Local Variables:
 // c-basic-offset: 4
 // End:
